<?php
/**
* @package phpBB Extension - UCP Sidebar
* @copyright (c) 2018 Sniper_E - https://www.sniper-e.com
* @license http://opensource.org/licenses/gpl-2.0.php GNU General Public License v2
*/

namespace sniper\ucpsidebar\event;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
* Event listener
*/
class listener implements EventSubscriberInterface
{

	/** @var \phpbb\request\request */
	protected $request;
	
	/* @var \phpbb\template\template */
	protected $template;

	/* @var \phpbb\user */
	protected $user;

	/**
	* Constructor
	*
	* @param \phpbb\config\config        $config             Config object
	* @param \phpbb\template\template    $template           Template object
	* @return \dmzx\fixednavbars\event\listener
	* @access public
	*/
	public function __construct(\phpbb\request\request $request, \phpbb\template\template $template, \phpbb\user $user)
	{
		$this->request  = $request;
		$this->template = $template;
		$this->user     = $user;
	}

	static public function getSubscribedEvents()
	{
		return array(
			'core.user_setup'                 => 'load_language_on_setup',
			'core.page_header'                => 'main',
			'core.ucp_prefs_view_data'        => 'ucp_prefs_get_data',
			'core.ucp_prefs_view_update_data' => 'ucp_prefs_set_data',
		);
	}

	public function load_language_on_setup($event)
	{
		$lang_set_ext = $event['lang_set_ext'];
		$lang_set_ext[] = array(
			'ext_name' => 'sniper/ucpsidebar',
			'lang_set' => 'ucpsidebar',
		);
		$event['lang_set_ext'] = $lang_set_ext;
	}

	public function main($event)
	{
		$this->template->assign_vars(array(
			'S_SIDEBAR_RIGHT' => !empty($this->user->data['user_sidebar_right']) ? true : false,
			'S_SIDEBAR_LIGHT' => !empty($this->user->data['user_sidebar_light']) ? true : false,
		));
	}
	
	public function ucp_prefs_get_data($event)
	{
		$event['data'] = array_merge($event['data'], array(
			'sidebar_right' => $this->request->variable('sidebar_right', (int) $this->user->data['user_sidebar_right']),
			'sidebar_light' => $this->request->variable('sidebar_light', (int) $this->user->data['user_sidebar_light']),
		));

		if (!$event['submit'])
		{
			$this->user->add_lang_ext('sniper/ucpsidebar', 'ucpsidebar_ucp');
			$this->template->assign_vars(array(
				'S_UCP_SIDEBAR_RIGHT' => $event['data']['sidebar_right'],
				'S_UCP_SIDEBAR_LIGHT' => $event['data']['sidebar_light'],
			));
		}
	}

	public function ucp_prefs_set_data($event)
	{
		$event['sql_ary'] = array_merge($event['sql_ary'], array(
			'user_sidebar_right' => $event['data']['sidebar_right'],
			'user_sidebar_light' => $event['data']['sidebar_light'],
		));
	}
}
